@@ -408,6 +408,19 @@ class Activity(TreeObject, TagsMixin, Activity2):
             return []
         return super().all_children()
 
+    def count_children(self, **kwargs) -> int:
+        """
+        Retrieve the number of child activities using a light-weight request.
+
+        :return: number of Activities
+        :rtype int
+        """
+        if self.activity_type != ActivityType.PROCESS:
+            raise IllegalArgumentError(
+                "You can only count the number of children of an Activity of type {}".format(ActivityType.PROCESS))
+
+        return super().count_children(method="activities", **kwargs)
+
     def clone(
         self,
         parent: Optional[Union['Activity', Text]] = None,
@@ -629,11 +642,12 @@ class Activity(TreeObject, TagsMixin, Activity2):
 
         # If both are empty that means the user is not interested in changing them
         if isinstance(assignees_ids, Empty) and isinstance(assignees, Empty):
-            return update_dict
+            pass
+
         # If one of them is None, then the assignees will be cleared from the Activity
         elif assignees is None or assignees_ids is None:
             update_dict['assignees_ids'] = list()
-            return update_dict
+
         # In case both of them have values specified, then an Error is raised
         elif assignees and assignees_ids and not isinstance(assignees, Empty) and not isinstance(assignees_ids, Empty):
             raise IllegalArgumentError('Provide either assignee names or their ids, but not both.')
@@ -641,19 +655,20 @@ class Activity(TreeObject, TagsMixin, Activity2):
         else:
             assignees = assignees if assignees is not None and not isinstance(assignees, Empty) else assignees_ids
 
-        if assignees:
-            if not isinstance(assignees, (list, tuple, set)) or not all(isinstance(a, (str, int)) for a in assignees):
-                raise IllegalArgumentError('All assignees must be provided as list, tuple or set of names or IDs.')
+            if assignees:
+                if not isinstance(assignees, (list, tuple, set)) or \
+                        not all(isinstance(a, (str, int)) for a in assignees):
+                    raise IllegalArgumentError('All assignees must be provided as list, tuple or set of names or IDs.')
 
-            update_assignees_ids = [m.get('id') for m in self.scope.members()
-                                    if m.get('id') in assignees or m.get('username') in set(assignees)]
+                update_assignees_ids = [m.get('id') for m in self.scope.members()
+                                        if m.get('id') in assignees or m.get('username') in set(assignees)]
 
-            if len(update_assignees_ids) != len(assignees):
-                raise NotFoundError('All assignees should be a member of the project.')
-        else:
-            update_assignees_ids = list()
+                if len(update_assignees_ids) != len(assignees):
+                    raise NotFoundError('All assignees should be a member of the project.')
+            else:
+                update_assignees_ids = list()
 
-        update_dict['assignees_ids'] = update_assignees_ids
+            update_dict['assignees_ids'] = update_assignees_ids
 
         if kwargs:
             update_dict.update(kwargs)
@@ -791,8 +806,15 @@ class Activity(TreeObject, TagsMixin, Activity2):
             self._widgets_manager = WidgetsManager(widgets=widgets, activity=self)
         return self._widgets_manager
 
-    def download_as_pdf(self, target_dir=None, pdf_filename=None, paper_size=PaperSize.A4,
-                        paper_orientation=PaperOrientation.PORTRAIT, include_appendices=False):
+    def download_as_pdf(
+            self,
+            target_dir: str = None,
+            pdf_filename: str = None,
+            paper_size: PaperSize = PaperSize.A4,
+            paper_orientation: PaperOrientation = PaperOrientation.PORTRAIT,
+            include_appendices: bool = False,
+            include_qr_code: bool = False,
+    ) -> Text:
         """
         Retrieve the PDF of the Activity.
 
@@ -815,8 +837,12 @@ class Activity(TreeObject, TagsMixin, Activity2):
         :type paper_size: basestring (see :class:`enums.PaperOrientation`)
         :param include_appendices: True if the PDF should contain appendices, False (default) if otherwise.
         :type include_appendices: bool
+        :param include_qr_code: True if the PDF should include a QR-code, False (default) if otherwise.
+        :type include_qr_code: bool
         :raises APIError: if the pdf file could not be found.
         :raises OSError: if the file could not be written.
+        :returns Path to the saved pdf file
+        :rtype str
         """
         if not pdf_filename:
             pdf_filename = self.name + '.pdf'
@@ -825,11 +851,12 @@ class Activity(TreeObject, TagsMixin, Activity2):
 
         full_path = os.path.join(target_dir or os.getcwd(), pdf_filename)
 
-        request_params = {
-            'papersize': paper_size,
-            'orientation': paper_orientation,
-            'appendices': include_appendices
-        }
+        request_params = dict(
+            papersize=check_enum(paper_size, PaperSize, "paper_size"),
+            orientation=check_enum(paper_orientation, PaperOrientation, "paper_orientation"),
+            appendices=check_type(include_appendices, bool, "include_appendices"),
+            includeqr=check_type(include_qr_code, bool, "include_qr_code"),
+        )
 
         url = self._client._build_url('activity_export', activity_id=self.id)
         response = self._client._request('GET', url, params=request_params)
@@ -853,7 +880,7 @@ class Activity(TreeObject, TagsMixin, Activity2):
                     with open(full_path, 'wb') as f:
                         for chunk in response.iter_content(1024):
                             f.write(chunk)
-                    return
+                    return full_path
 
                 count += ASYNC_REFRESH_INTERVAL
                 time.sleep(ASYNC_REFRESH_INTERVAL)
@@ -865,6 +892,8 @@ class Activity(TreeObject, TagsMixin, Activity2):
             for chunk in response.iter_content(1024):
                 f.write(chunk)
 
+        return full_path
+
     def move(self, parent, classification=None):
         """
         Move the `Activity` to a new parent.
@@ -908,7 +937,7 @@ class Activity(TreeObject, TagsMixin, Activity2):
 
         response = self._client._request('POST', url, data=params)
 
-        if response.status_code != requests.codes.created:  # pragma: no cover
+        if response.status_code not in (requests.codes.created, requests.codes.accepted):  # pragma: no cover
             raise APIError("Could not share the link to Activity {}".format(self), response=response)
 
     def share_pdf(
@@ -918,7 +947,8 @@ class Activity(TreeObject, TagsMixin, Activity2):
             recipient_users: List[Union[User, Text]],
             paper_size: Optional[PaperSize] = PaperSize.A3,
             paper_orientation: Optional[PaperOrientation] = PaperOrientation.PORTRAIT,
-            include_appendices: Optional[bool] = False
+            include_appendices: Optional[bool] = False,
+            include_qr_code: Optional[bool] = False,
     ) -> None:
         """
         Share the PDF of the `Activity` through email.
@@ -942,6 +972,8 @@ class Activity(TreeObject, TagsMixin, Activity2):
         :type paper_size: basestring (see :class:`enums.PaperOrientation`)
         :param include_appendices: True if the PDF should contain appendices, False (default) if otherwise.
         :type include_appendices: bool
+        :param include_qr_code: True if the PDF should include a QR-code, False (default) if otherwise.
+        :type include_qr_code: bool
         :raises APIError: if an internal server error occurred.
         """
         recipient_emails = list()
@@ -957,19 +989,20 @@ class Activity(TreeObject, TagsMixin, Activity2):
                                        '"{}" ({}) is not.'.format(recipient_users, type(recipient_users)))
 
         params = dict(
-            message=check_text(message, 'message'),
-            subject=check_text(subject, 'subject'),
+            message=check_text(message, "message"),
+            subject=check_text(subject, "subject"),
             recipient_users=recipient_users_ids,
             recipient_emails=recipient_emails,
             activity_id=self.id,
-            papersize=check_enum(paper_size, PaperSize, 'paper_size'),
-            orientation=check_enum(paper_orientation, PaperOrientation, 'paper_orientation'),
-            appendices=check_type(include_appendices, bool, 'bool'),
+            papersize=check_enum(paper_size, PaperSize, "paper_size"),
+            orientation=check_enum(paper_orientation, PaperOrientation, "paper_orientation"),
+            appendices=check_type(include_appendices, bool, "include_appendices"),
+            includeqr=check_type(include_qr_code, bool, "include_qr_code"),
         )
 
         url = self._client._build_url('notification_share_activity_pdf')
 
         response = self._client._request('POST', url, data=params)
 
-        if response.status_code != requests.codes.created:  # pragma: no cover
+        if response.status_code not in (requests.codes.created, requests.codes.accepted):  # pragma: no cover
             raise APIError("Could not share the link to Activity {}".format(self), response=response)
