@@ -1,6 +1,9 @@
-from abc import ABC
+from abc import ABC, abstractmethod
 from typing import Optional, Text, List, TypeVar
 
+import requests
+
+from pykechain.exceptions import NotFoundError
 from pykechain.models import BaseInScope
 
 T = TypeVar('T')
@@ -85,6 +88,33 @@ class TreeObject(BaseInScope, ABC):
 
         return all_children
 
+    @abstractmethod
+    def count_children(self, method: Text, **kwargs) -> int:
+        """
+        Retrieve the number of child objects using a light-weight request.
+
+        :param method: which type of object to retrieve, either parts or activities
+        :type method: str
+        :return: number of child objects
+        :rtype int
+        """
+        parameters = {
+            "scope_id": self.scope_id,
+            "parent_id": self.id,
+            "limit": 1
+        }
+        if kwargs:
+            parameters.update(kwargs)
+
+        response = self._client._request('GET', self._client._build_url(method), params=parameters)
+
+        if response.status_code != requests.codes.ok:  # pragma: no cover
+            raise NotFoundError("Could not retrieve {}".format(method))
+
+        count = response.json()['count']
+
+        return count
+
     def _populate_cached_children(
             self,
             all_descendants: List[T],
