@@ -14,12 +14,20 @@ from pykechain.enums import (
     CardWidgetImageValue,
 )
 from pykechain.exceptions import IllegalArgumentError
-from pykechain.models.input_checks import check_enum
+from pykechain.models.input_checks import check_enum, check_base
 from pykechain.models.value_filter import PropertyValueFilter
+from pykechain.models.widgets.enums import MetaWidget, AssociatedObjectId
 from pykechain.utils import is_uuid, snakecase, camelcase
 
 # these are the common keys to all kecards.
-KECARD_COMMON_KEYS = ["collapsed", "collapsible", "noBackground", "noPadding", "isDisabled", "isMerged"]
+KECARD_COMMON_KEYS = [MetaWidget.COLLAPSED,
+                      MetaWidget.COLLAPSIBLE,
+                      MetaWidget.NO_BACKGROUND,
+                      MetaWidget.NO_PADDING,
+                      MetaWidget.IS_DISABLED,
+                      MetaWidget.IS_MERGED]
+
+TITLE_TYPING = Optional[Union[type(None), Text, bool]]
 
 
 def _retrieve_object(obj: Union['Base', Text], method: Callable) -> Union['Base']:
@@ -74,7 +82,7 @@ def _retrieve_object_id(obj: Optional[Union['Base', Text]]) -> Optional[Text]:
 
 def _set_title(
         meta: Dict,
-        title: Optional[Union[Text, bool]] = None,
+        title: TITLE_TYPING = None,
         show_title_value: Optional[WidgetTitleValue] = None,
         **kwargs
 ) -> Tuple[Dict, Text]:
@@ -114,8 +122,8 @@ def _set_title(
         title = None
 
     meta.update({
-        "showTitleValue": show_title_value,
-        "customTitle": title,
+        MetaWidget.SHOW_TITLE_VALUE: show_title_value,
+        MetaWidget.CUSTOM_TITLE: title,
     })
     return meta, title
 
@@ -143,16 +151,16 @@ def _set_description(
     :raises IllegalArgumentError: When description is neither str, bool or None.
     """
     if description is False or description is None:
-        show_description_value = "No description"
+        show_description_value = MetaWidget.DESCRIPTION_OPTION_NOTHING
         description = ""
     elif isinstance(description, str):
-        show_description_value = "Custom description"
+        show_description_value = MetaWidget.DESCRIPTION_OPTION_CUSTOM
     else:
         raise IllegalArgumentError("When using the add_card_widget or add_service_card_widget, 'description' must be "
                                    "'text_type' or None or False. Type is: {}".format(type(description)))
     meta.update({
-        "showDescriptionValue": show_description_value,
-        "customDescription": description
+        MetaWidget.SHOW_DESCRIPTION_VALUE: show_description_value,
+        MetaWidget.CUSTOM_DESCRIPTION: description
     })
     return meta
 
@@ -197,33 +205,33 @@ def _set_link(
             default_link_value = CardWidgetLinkValue.TREE_VIEW
 
         meta.update({
-            'customLink': link.id,
-            'showLinkValue': default_link_value,
+            MetaWidget.CUSTOM_LINK: link.id,
+            MetaWidget.SHOW_LINK_VALUE: default_link_value,
         })
     elif isinstance(link, str) and is_uuid(link):
         meta.update({
-            'customLink': link,
-            'showLinkValue': CardWidgetLinkValue.TASK_LINK,
+            MetaWidget.CUSTOM_LINK: link,
+            MetaWidget.SHOW_LINK_VALUE: CardWidgetLinkValue.TASK_LINK,
         })
     elif link is None or link is False:
         meta.update({
-            'customLink': None,
-            'showLinkValue': CardWidgetLinkValue.NO_LINK,
+            MetaWidget.CUSTOM_LINK: None,
+            MetaWidget.SHOW_LINK_VALUE: CardWidgetLinkValue.NO_LINK,
         })
     elif link in KEChainPages.values():
         meta.update({
-            'customLink': "",
-            'showLinkValue': CardWidgetKEChainPageLink[link],
+            MetaWidget.CUSTOM_LINK: "",
+            MetaWidget.SHOW_LINK_VALUE: CardWidgetKEChainPageLink[link],
         })
     else:
         meta.update({
-            'customLink': link,
-            'showLinkValue': CardWidgetLinkValue.EXTERNAL_LINK,
+            MetaWidget.CUSTOM_LINK: link,
+            MetaWidget.SHOW_LINK_VALUE: CardWidgetLinkValue.EXTERNAL_LINK,
         })
 
     if link_value is not None:
         meta.update({
-            'showLinkValue': check_enum(link_value, CardWidgetLinkValue, 'link_value'),
+            MetaWidget.SHOW_LINK_VALUE: check_enum(link_value, CardWidgetLinkValue, 'link_value'),
         })
 
     return meta
@@ -252,29 +260,29 @@ def _set_image(
     :rtype: dict
     :raises IllegalArgumentError: When illegal `image` type is used.
     """
-    meta['imageFit'] = check_enum(image_fit, ImageFitValue, 'image_fit')
+    meta[MetaWidget.IMAGE_FIT] = check_enum(image_fit, ImageFitValue, 'image_fit')
 
     from pykechain.models import Property
     if isinstance(image, Property) and image.type == PropertyType.ATTACHMENT_VALUE:
         meta.update({
-            'customImage': "/api/v3/properties/{}/preview".format(image.id),
-            'showImageValue': CardWidgetImageValue.CUSTOM_IMAGE
+            MetaWidget.CUSTOM_IMAGE: "/api/v3/properties/{}/preview".format(image.id),
+            MetaWidget.SHOW_IMAGE_VALUE: CardWidgetImageValue.CUSTOM_IMAGE
         })
     elif image is None:
         meta.update({
-            'customImage': None,
-            'showImageValue': CardWidgetImageValue.NO_IMAGE
+            MetaWidget.CUSTOM_IMAGE: None,
+            MetaWidget.SHOW_IMAGE_VALUE: CardWidgetImageValue.NO_IMAGE
         })
     else:
-        raise IllegalArgumentError("When using the add_card_widget or add_service_card_widget, 'description' must be "
-                                   "'text_type' or None or False. Type is: {}".format(type(image)))
+        raise IllegalArgumentError("When using the add_card_widget or add_service_card_widget, 'image' must be an "
+                                   "'AttachmentProperty' or None. Type is: {}".format(type(image)))
     return meta
 
 
 def _set_button_text(
         meta: Dict,
         service: 'Service',
-        custom_button_text: Optional[Text] = False,
+        custom_button_text: TITLE_TYPING = False,
         **kwargs
 ) -> Dict:
     """
@@ -299,17 +307,17 @@ def _set_button_text(
     :raises IllegalArgumentError: When illegal (combination) of arguments are set.
     """
     if custom_button_text is False:
-        show_button_value = "Default"
+        show_button_value = MetaWidget.BUTTON_TEXT_DEFAULT
         button_text = service.name
     elif custom_button_text is None:
-        show_button_value = "No text"
-        button_text = ''
+        show_button_value = MetaWidget.BUTTON_NO_TEXT
+        button_text = str()
     else:
-        show_button_value = "Custom text"
+        show_button_value = MetaWidget.BUTTON_TEXT_CUSTOM
         button_text = str(custom_button_text)
     meta.update({
-        'showButtonValue': show_button_value,
-        'customText': button_text,
+        MetaWidget.SHOW_BUTTON_VALUE: show_button_value,
+        MetaWidget.CUSTOM_TEXT: button_text,
     })
     return meta
 
@@ -335,7 +343,7 @@ def _initiate_meta(kwargs, activity, ignores=()):
     :return: kecard dictionary
     :rtype: dict
     """
-    meta = dict(activityId=str(_retrieve_object_id(activity)))
+    meta = {AssociatedObjectId.ACTIVITY_ID: str(_retrieve_object_id(activity))}
     # also add the keys' in their snake case appearance so noPadding and no_padding, customHeight and custom_height
     keys_in_kwargs = KECARD_COMMON_KEYS + [snakecase(k) for k in KECARD_COMMON_KEYS]
 
@@ -345,8 +353,8 @@ def _initiate_meta(kwargs, activity, ignores=()):
             meta[camelcase(key)] = kwargs.pop(key)
 
     # we check for custom_height specifically and deal with it.
-    if snakecase('customHeight') in kwargs:
-        meta['customHeight'] = kwargs.pop(snakecase("customHeight"))
+    if snakecase(MetaWidget.CUSTOM_HEIGHT) in kwargs:
+        meta[MetaWidget.CUSTOM_HEIGHT] = kwargs.pop(snakecase(MetaWidget.CUSTOM_HEIGHT))
 
     # remove the 'ignores' from the meta
     for key in ignores:
@@ -367,9 +375,9 @@ def _check_prefilters(part_model: 'Part', prefilters: Union[Dict, List]) -> List
     :raises IllegalArgumentError: when the type of the input is provided incorrect.
     """
     if isinstance(prefilters, dict):
-        property_models = prefilters.get('property_models', [])  # type: List[Property, Text]  # noqa
-        values = prefilters.get('values', [])
-        filters_type = prefilters.get('filters_type', [])
+        property_models = prefilters.get(MetaWidget.PROPERTY_MODELS, [])  # type: List[Property, Text]  # noqa
+        values = prefilters.get(MetaWidget.VALUES, [])
+        filters_type = prefilters.get(MetaWidget.FILTERS_TYPE, [])
 
         if any(len(lst) != len(property_models) for lst in [values, filters_type]):
             raise IllegalArgumentError('The lists of "property_models", "values" and "filters_type" should be the '
@@ -389,7 +397,8 @@ def _check_prefilters(part_model: 'Part', prefilters: Union[Dict, List]) -> List
     elif not all(isinstance(pf, PropertyValueFilter) for pf in prefilters):
         raise IllegalArgumentError("`prefilters` must be a list of PropertyValueFilter objects.")
 
-    [pf.validate(part_model=part_model) for pf in prefilters]
+    if part_model:
+        [pf.validate(part_model=part_model) for pf in prefilters]
 
     return prefilters
 
@@ -407,6 +416,10 @@ def _check_excluded_propmodels(part_model: 'Part', property_models: List['AnyPro
     from pykechain.models import Property
     from pykechain.models import Part
 
+    if not part_model:
+        # part model is unknown, only check for property_models
+        return [check_base(pm, Property, "property_model") for pm in property_models]
+
     if not isinstance(part_model, Part):
         raise IllegalArgumentError('`part_model` must be a Part object, "{}" is not.'.format(part_model))
 
