@@ -1,24 +1,26 @@
+import os
+from typing import List
 from unittest import TestCase
 
 from pykechain.enums import (WidgetTypes, ShowColumnTypes, FilterType, ProgressBarColors,
                              Category, LinkTargets, KEChainPages, WidgetTitleValue, Alignment, ActivityType,
                              CardWidgetLinkValue, CardWidgetLinkTarget, ImageFitValue, PropertyType, Classification,
-                             Multiplicity)
+                             Multiplicity, ActivityStatus, ActivityClassification)
 from pykechain.models.widgets.enums import (
     DashboardWidgetShowTasks,
     DashboardWidgetShowScopes,
-)
+    TasksAssignmentFilterTypes)
 from pykechain.exceptions import IllegalArgumentError, NotFoundError
 from pykechain.models import Activity, Part
 from pykechain.models.widgets import (
     UndefinedWidget, HtmlWidget, PropertygridWidget, AttachmentviewerWidget, SupergridWidget, FilteredgridWidget,
     TasknavigationbarWidget, SignatureWidget, ServiceWidget, NotebookWidget, MulticolumnWidget, CardWidget,
-    MetapanelWidget, ScopeWidget)
+    MetapanelWidget, ScopeWidget, TasksWidget)
 from pykechain.models.widgets.helpers import _set_title
 from pykechain.models.widgets.widget import Widget
-from pykechain.models.widgets.widget_models import ServicecardWidget, DashboardWidget
+from pykechain.models.widgets.widget_models import ServicecardWidget, DashboardWidget, ScopemembersWidget
 from pykechain.models.widgets.widgets_manager import WidgetsManager
-from pykechain.utils import slugify_ref
+from pykechain.utils import slugify_ref, temp_chdir, find
 from tests.classes import TestBetamax
 
 
@@ -753,6 +755,7 @@ class TestWidgetManagerInActivity(TestBetamax):
         self.assertIsInstance(new_widgets, list)
         self.assertTrue(all(isinstance(w, Widget) for w in new_widgets))
         self.assertEqual(len(new_widgets), 2)
+        self.assertIn(new_widgets[0], self.wm._widgets)
 
         # tearDown
         [w.delete() for w in new_widgets]
@@ -818,7 +821,28 @@ class TestWidgetManagerInActivity(TestBetamax):
 
         self.assertTrue(widget_current_project.meta['showAssignees'])
         self.assertFalse(widget_tagged_projects.meta['showAssignees'])
-        return
+
+    def test_add_tasks_widget(self):
+        tasks_widget = self.wm.add_tasks_widget()
+
+        self.assertIsInstance(tasks_widget, TasksWidget)
+
+    def test_add_tasks_widget_with_filters(self):
+        tasks_widget = self.wm.add_tasks_widget(
+            parent_activity=self.wm.activity.parent(),
+            status_filter=ActivityStatus.OPEN,
+            assigned_filter=TasksAssignmentFilterTypes.FILTER_ASSIGNED_TO_USER,
+            activity_type_filter=ActivityType.TASK,
+            classification_filter=ActivityClassification.CATALOG,
+            tags_filter=["One", "Two", "Five"],
+        )
+
+        self.assertIsInstance(tasks_widget, TasksWidget)
+
+    def test_add_scopemembers_widget(self):
+        scope_members_widget = self.wm.add_scopemembers_widget()
+
+        self.assertIsInstance(scope_members_widget, ScopemembersWidget)
 
 
 class TestWidgetManagerWeatherWidget(TestBetamax):
@@ -992,3 +1016,60 @@ class TestWidgetsCopyMove(TestBetamax):
         self.assertEqual(widget_manager_2[0].title, title)
         self.assertTrue(all(prop.output for prop in associated_model.properties))
         self.assertEqual(1, len(self.task.widgets()))
+
+
+class TestWidgetDownloadAsExcel(TestBetamax):
+
+    def setUp(self):
+        super().setUp()
+        task = self.project.activity(name="Task - Form + Tables + Service")
+        all_widgets = task.widgets()  # type: List[Widget]
+
+        self.grid_widget = find(all_widgets, lambda w: w.widget_type == WidgetTypes.FILTEREDGRID)
+        self.form_widget = find(all_widgets, lambda w: w.widget_type == WidgetTypes.PROPERTYGRID)
+
+    def tearDown(self):
+        super().tearDown()
+
+    def test_download_as_excel(self):
+        file_name = "My excel file"
+
+        with temp_chdir() as target_dir:
+
+            path = self.grid_widget.download_as_excel(
+                target_dir=target_dir,
+                file_name=file_name,
+            )
+
+            self.assertTrue(os.path.exists(path))
+            self.assertIn(slugify_ref(file_name), path)
+
+    def test_timezone_aware(self):
+        file_name = "My excel file.xls"
+        user = self.client.user("testuser")
+        timezone_definition = user._json_data['timezone']
+
+        self.assertEqual("Europe/Amsterdam", timezone_definition)
+
+        with temp_chdir() as target_dir:
+            path = self.grid_widget.download_as_excel(
+                target_dir=target_dir,
+                file_name=file_name,
+                user=user,
+            )
+
+            self.assertTrue(os.path.exists(path))
+
+    # noinspection PyTypeChecker
+    def test_invalid_inputs(self):
+        with self.assertRaises(IllegalArgumentError):
+            self.form_widget.download_as_excel()
+
+        with self.assertRaises(IllegalArgumentError):
+            self.grid_widget.download_as_excel(target_dir=3)
+
+        with self.assertRaises(IllegalArgumentError):
+            self.grid_widget.download_as_excel(file_name=15.3)
+
+        with self.assertRaises(IllegalArgumentError):
+            self.grid_widget.download_as_excel(user="Testuser")
